@@ -24,7 +24,7 @@ let get_winsize tty =
   let width = Ctypes.(allocate int) 0 in
   let height = Ctypes.(allocate int) 0 in
   C.Functions.TTY.get_winsize tty width height
-  |> Error.to_result_lazy (fun () -> Ctypes.(!@ width, !@ height))
+  |> Error.to_result_f (fun () -> Ctypes.(!@ width, !@ height))
 
 module Vterm_state = C.Types.TTY.Vterm_state
 
@@ -34,4 +34,4 @@ let set_vterm_state =
 let get_vterm_state () =
   let state = Ctypes.allocate_n C.Types.TTY.Vterm_state.t ~count:1 in
   C.Functions.TTY.get_vterm_state state
-  |> Error.to_result_lazy (fun () -> Ctypes.(!@) state)
+  |> Error.to_result_f (fun () -> Ctypes.(!@) state)
