@@ -142,10 +142,16 @@ static void luv_fs_event_trampoline(
 {
     caml_acquire_runtime_system();
     CAMLparam0();
-    CAMLlocal1(callback);
+    CAMLlocal2(callback, option);
     GET_HANDLE_CALLBACK(LUV_GENERIC_CALLBACK);
+    if (filename == NULL)
+        option = Val_int(0);
+    else {
+        option = caml_alloc_small(1, 0);
+        Field(option, 0) = caml_copy_string(filename);
+    }
     caml_callback3(
-        callback, caml_copy_string(filename), Val_int(events), Val_int(status));
+        callback, option, Val_int(events), Val_int(status));
     CAMLdrop;
     caml_release_runtime_system();
 }
@@ -175,7 +181,8 @@ static void luv_getaddrinfo_trampoline(
 }
 
 static void luv_getnameinfo_trampoline(
-    uv_getnameinfo_t *c_request, int status, char *hostname, char *service)
+    uv_getnameinfo_t *c_request, int status, const char *hostname,
+    const char *service)
 {
     caml_acquire_runtime_system();
     value callback;
@@ -195,7 +202,7 @@ static void luv_idle_trampoline(uv_idle_t *c_handle)
 
 uv_key_t luv_once_callback_key;
 
-static void luv_once_trampoline()
+static void luv_once_trampoline(void)
 {
     value callback = (value)uv_key_get(&luv_once_callback_key);
     caml_callback(callback, Val_unit);
@@ -337,152 +344,152 @@ static void luv_write_trampoline(uv_write_t *c_request, int status)
     caml_release_runtime_system();
 }
 
-uv_after_work_cb luv_get_after_work_trampoline()
+uv_after_work_cb luv_get_after_work_trampoline(void)
 {
     return luv_after_work_trampoline;
 }
 
-uv_alloc_cb luv_get_alloc_trampoline()
+uv_alloc_cb luv_get_alloc_trampoline(void)
 {
     return luv_alloc_trampoline;
 }
 
-uv_async_cb luv_get_async_trampoline()
+uv_async_cb luv_get_async_trampoline(void)
 {
     return luv_async_trampoline;
 }
 
-uv_check_cb luv_get_check_trampoline()
+uv_check_cb luv_get_check_trampoline(void)
 {
     return luv_check_trampoline;
 }
 
-uv_close_cb luv_get_close_trampoline()
+uv_close_cb luv_get_close_trampoline(void)
 {
     return luv_close_trampoline;
 }
 
-uv_connect_cb luv_get_connect_trampoline()
+uv_connect_cb luv_get_connect_trampoline(void)
 {
     return luv_connect_trampoline;
 }
 
-uv_connection_cb luv_get_connection_trampoline()
+uv_connection_cb luv_get_connection_trampoline(void)
 {
     return luv_connection_trampoline;
 }
 
-uv_exit_cb luv_get_exit_trampoline()
+uv_exit_cb luv_get_exit_trampoline(void)
 {
     return luv_exit_trampoline;
 }
 
-uv_exit_cb luv_null_exit_trampoline()
+uv_exit_cb luv_null_exit_trampoline(void)
 {
     return NULL;
 }
 
-uv_fs_cb luv_get_fs_trampoline()
+uv_fs_cb luv_get_fs_trampoline(void)
 {
     return luv_fs_trampoline;
 }
 
-uv_fs_cb luv_null_fs_callback_pointer()
+uv_fs_cb luv_null_fs_callback_pointer(void)
 {
     return NULL;
 }
 
-luv_fs_event_cb luv_get_fs_event_trampoline()
+luv_fs_event_cb luv_get_fs_event_trampoline(void)
 {
     return luv_fs_event_trampoline;
 }
 
-luv_fs_poll_cb luv_get_fs_poll_trampoline()
+luv_fs_poll_cb luv_get_fs_poll_trampoline(void)
 {
     return luv_fs_poll_trampoline;
 }
 
-uv_getaddrinfo_cb luv_get_getaddrinfo_trampoline()
+uv_getaddrinfo_cb luv_get_getaddrinfo_trampoline(void)
 {
     return luv_getaddrinfo_trampoline;
 }
 
-luv_getnameinfo_cb luv_get_getnameinfo_trampoline()
+uv_getnameinfo_cb luv_get_getnameinfo_trampoline(void)
 {
     return luv_getnameinfo_trampoline;
 }
 
-uv_idle_cb luv_get_idle_trampoline()
+uv_idle_cb luv_get_idle_trampoline(void)
 {
     return luv_idle_trampoline;
 }
 
-luv_once_cb luv_get_once_trampoline()
+luv_once_cb luv_get_once_trampoline(void)
 {
     return luv_once_trampoline;
 }
 
-uv_poll_cb luv_get_poll_trampoline()
+uv_poll_cb luv_get_poll_trampoline(void)
 {
     return luv_poll_trampoline;
 }
 
-uv_prepare_cb luv_get_prepare_trampoline()
+uv_prepare_cb luv_get_prepare_trampoline(void)
 {
     return luv_prepare_trampoline;
 }
 
-uv_random_cb luv_get_random_trampoline()
+uv_random_cb luv_get_random_trampoline(void)
 {
     return luv_random_trampoline;
 }
 
-uv_random_cb luv_null_random_trampoline()
+uv_random_cb luv_null_random_trampoline(void)
 {
     return NULL;
 }
 
-luv_read_cb luv_get_read_trampoline()
+luv_read_cb luv_get_read_trampoline(void)
 {
     return luv_read_trampoline;
 }
 
-luv_udp_recv_cb luv_get_recv_trampoline()
+luv_udp_recv_cb luv_get_recv_trampoline(void)
 {
     return luv_recv_trampoline;
 }
 
-uv_udp_send_cb luv_get_send_trampoline()
+uv_udp_send_cb luv_get_send_trampoline(void)
 {
     return luv_send_trampoline;
 }
 
-uv_shutdown_cb luv_get_shutdown_trampoline()
+uv_shutdown_cb luv_get_shutdown_trampoline(void)
 {
     return luv_shutdown_trampoline;
 }
 
-uv_signal_cb luv_get_signal_trampoline()
+uv_signal_cb luv_get_signal_trampoline(void)
 {
     return luv_signal_trampoline;
 }
 
-uv_thread_cb luv_get_thread_trampoline()
+uv_thread_cb luv_get_thread_trampoline(void)
 {
     return luv_thread_trampoline;
 }
 
-uv_timer_cb luv_get_timer_trampoline()
+uv_timer_cb luv_get_timer_trampoline(void)
 {
     return luv_timer_trampoline;
 }
 
-uv_work_cb luv_get_work_trampoline()
+uv_work_cb luv_get_work_trampoline(void)
 {
     return luv_work_trampoline;
 }
 
-uv_write_cb luv_get_write_trampoline()
+uv_write_cb luv_get_write_trampoline(void)
 {
     return luv_write_trampoline;
 }
@@ -530,12 +537,12 @@ static void luv_c_work_trampoline(uv_work_t *c_request)
     function(argument);
 }
 
-uv_after_work_cb luv_get_after_c_work_trampoline()
+uv_after_work_cb luv_get_after_c_work_trampoline(void)
 {
     return luv_after_c_work_trampoline;
 }
 
-uv_work_cb luv_get_c_work_trampoline()
+uv_work_cb luv_get_c_work_trampoline(void)
 {
     return luv_c_work_trampoline;
 }
@@ -579,7 +586,7 @@ CAMLprim value luv_set_once_callback(value callback)
 
 // Warning-suppressing wrappers.
 
-char* luv_version_string()
+char* luv_version_string(void)
 {
     return (char*)uv_version_string();
 }
@@ -613,15 +620,6 @@ int luv_fs_poll_start(
     return uv_fs_poll_start(handle, (uv_fs_poll_cb)poll_cb, path, interval);
 }
 
-int luv_getnameinfo(
-    uv_loop_t *loop, uv_getnameinfo_t *req, luv_getnameinfo_cb getnameinfo_cb,
-    const struct sockaddr *addr, int flags)
-{
-    return
-        uv_getnameinfo(
-            loop, req, (uv_getnameinfo_cb)getnameinfo_cb, addr, flags);
-}
-
 int luv_read_start(
     uv_stream_t *stream, uv_alloc_cb alloc_cb, luv_read_cb read_cb)
 {
@@ -641,9 +639,27 @@ int luv_os_uname(char *buffer)
 
 
 
+// String conversion functions.
+
+size_t luv_utf16_length_as_wtf8(const char *utf16, ssize_t utf16_len)
+{
+    return uv_utf16_length_as_wtf8((const uint16_t*)utf16, utf16_len);
+}
+
+int luv_utf16_to_wtf8(
+    const char *utf16, ssize_t utf16_len, char **wtf8_ptr,
+    size_t *wtf8_len_ptr)
+{
+    return
+        uv_utf16_to_wtf8(
+            (const uint16_t*)utf16, utf16_len, wtf8_ptr, wtf8_len_ptr);
+}
+
+
+
 // Other helpers.
 
-char* luv_version_suffix()
+char* luv_version_suffix(void)
 {
     return UV_VERSION_SUFFIX;
 }
