@@ -45,7 +45,7 @@ typedef ADDRESS_FAMILY sa_family_t;
 // that is passed to them by libuv, and call it.
 
 // Not declared by libuv.
-typedef void (*luv_once_cb)();
+typedef void (*luv_once_cb)(void);
 
 // Differ from libuv declarations in const-ness of arguments. See "Warning
 // suppression" below.
@@ -55,45 +55,42 @@ typedef void (*luv_fs_event_cb)(
 typedef void (*luv_fs_poll_cb)(
     uv_fs_poll_t *handle, int status, uv_stat_t *prev, uv_stat_t *curr);
 
-typedef void (*luv_getnameinfo_cb)(
-    uv_getnameinfo_t *req, int status, char *hostname, char *service);
-
 typedef void (*luv_read_cb)(uv_stream_t *stream, ssize_t nread, uv_buf_t *buf);
 
 typedef void (*luv_udp_recv_cb)(
     uv_udp_t *handle, ssize_t nread, uv_buf_t *buf, struct sockaddr *addr,
     unsigned int flags);
 
-uv_after_work_cb luv_get_after_work_trampoline();
-uv_alloc_cb luv_get_alloc_trampoline();
-uv_async_cb luv_get_async_trampoline();
-uv_check_cb luv_get_check_trampoline();
-uv_close_cb luv_get_close_trampoline();
-uv_connect_cb luv_get_connect_trampoline();
-uv_connection_cb luv_get_connection_trampoline();
-uv_exit_cb luv_get_exit_trampoline();
-uv_exit_cb luv_null_exit_trampoline();
-uv_fs_cb luv_get_fs_trampoline();
-uv_fs_cb luv_null_fs_callback_pointer();
-luv_fs_event_cb luv_get_fs_event_trampoline();
-luv_fs_poll_cb luv_get_fs_poll_trampoline();
-uv_getaddrinfo_cb luv_get_getaddrinfo_trampoline();
-luv_getnameinfo_cb luv_get_getnameinfo_trampoline();
-uv_idle_cb luv_get_idle_trampoline();
-luv_once_cb luv_get_once_trampoline();
-uv_poll_cb luv_get_poll_trampoline();
-uv_prepare_cb luv_get_prepare_trampoline();
-uv_random_cb luv_get_random_trampoline();
-uv_random_cb luv_null_random_trampoline();
-luv_read_cb luv_get_read_trampoline();
-luv_udp_recv_cb luv_get_recv_trampoline();
-uv_udp_send_cb luv_get_send_trampoline();
-uv_shutdown_cb luv_get_shutdown_trampoline();
-uv_signal_cb luv_get_signal_trampoline();
-uv_thread_cb luv_get_thread_trampoline();
-uv_timer_cb luv_get_timer_trampoline();
-uv_work_cb luv_get_work_trampoline();
-uv_write_cb luv_get_write_trampoline();
+uv_after_work_cb luv_get_after_work_trampoline(void);
+uv_alloc_cb luv_get_alloc_trampoline(void);
+uv_async_cb luv_get_async_trampoline(void);
+uv_check_cb luv_get_check_trampoline(void);
+uv_close_cb luv_get_close_trampoline(void);
+uv_connect_cb luv_get_connect_trampoline(void);
+uv_connection_cb luv_get_connection_trampoline(void);
+uv_exit_cb luv_get_exit_trampoline(void);
+uv_exit_cb luv_null_exit_trampoline(void);
+uv_fs_cb luv_get_fs_trampoline(void);
+uv_fs_cb luv_null_fs_callback_pointer(void);
+luv_fs_event_cb luv_get_fs_event_trampoline(void);
+luv_fs_poll_cb luv_get_fs_poll_trampoline(void);
+uv_getaddrinfo_cb luv_get_getaddrinfo_trampoline(void);
+uv_getnameinfo_cb luv_get_getnameinfo_trampoline(void);
+uv_idle_cb luv_get_idle_trampoline(void);
+luv_once_cb luv_get_once_trampoline(void);
+uv_poll_cb luv_get_poll_trampoline(void);
+uv_prepare_cb luv_get_prepare_trampoline(void);
+uv_random_cb luv_get_random_trampoline(void);
+uv_random_cb luv_null_random_trampoline(void);
+luv_read_cb luv_get_read_trampoline(void);
+luv_udp_recv_cb luv_get_recv_trampoline(void);
+uv_udp_send_cb luv_get_send_trampoline(void);
+uv_shutdown_cb luv_get_shutdown_trampoline(void);
+uv_signal_cb luv_get_signal_trampoline(void);
+uv_thread_cb luv_get_thread_trampoline(void);
+uv_timer_cb luv_get_timer_trampoline(void);
+uv_work_cb luv_get_work_trampoline(void);
+uv_write_cb luv_get_write_trampoline(void);
 
 // Handles can have multiple outstanding callbacks, so the corresponding OCaml
 // closures are stored in an array. These are the indices into that array for
@@ -137,8 +134,8 @@ enum {
 // Helpers for setting up uv_queue_work requests that call a C function.
 int luv_add_c_function_and_argument(
     uv_work_t *c_request, intnat function, intnat argument);
-uv_after_work_cb luv_get_after_c_work_trampoline();
-uv_work_cb luv_get_c_work_trampoline();
+uv_after_work_cb luv_get_after_c_work_trampoline(void);
+uv_work_cb luv_get_c_work_trampoline(void);
 
 // Helper for calling uv_thread_create with the address of a C function.
 int luv_thread_create_c(
@@ -160,7 +157,7 @@ CAMLprim value luv_set_once_callback(value callback);
 // Ctypes is unable to emit the correct cv-qualifiers, so binding the libuv
 // functions directly with Ctypes results in noisy warnings. These wrappers
 // suppress the warnings by performing const_casts.
-char* luv_version_string();
+char* luv_version_string(void);
 char* luv_req_type_name(uv_req_type type);
 char* luv_fs_get_path(const uv_fs_t *req);
 char* luv_dlerror(const uv_lib_t *lib);
@@ -173,10 +170,6 @@ int luv_fs_poll_start(
     uv_fs_poll_t *handle, luv_fs_poll_cb poll_cb, const char *path,
     unsigned int interval);
 
-int luv_getnameinfo(
-    uv_loop_t *loop, uv_getnameinfo_t *req, luv_getnameinfo_cb getnameinfo_cb,
-    const struct sockaddr *addr, int flags);
-
 int luv_read_start(
     uv_stream_t *stream, uv_alloc_cb alloc_cb, luv_read_cb read_cb);
 
@@ -188,10 +181,24 @@ int luv_os_uname(char *buffer);
 
 
 
+// String conversion functions. These are wrapped because it is convenient to
+// use Ctypes to pass OCaml strings directly to C code, but the Ctypes type
+// combinator for that purpose only compiles against C arguments of types such
+// as char*, and not uint16_t*. So these helpers add the necessary casts to
+// satisfy Ctypes.
+
+size_t luv_utf16_length_as_wtf8(const char *utf16, ssize_t utf16_len);
+
+int luv_utf16_to_wtf8(
+    const char *utf16, ssize_t utf16_len, char **wtf8_ptr,
+    size_t *wtf8_len_ptr);
+
+
+
 // Miscellaneous helpers - other things that are easiest to do in C.
 
 // Ctypes.constant can't bind a char*, so we return it instead.
-char* luv_version_suffix();
+char* luv_version_suffix(void);
 
 // The arguments to uv_spawn involve complex-enough C data, that it is easiest
 // to create a wrapper function that takes simple arguments, and create the
