@@ -61,6 +61,7 @@ struct
     let enetunreach = constant "UV_ENETUNREACH" int
     let enfile = constant "UV_ENFILE" int
     let enobufs = constant "UV_ENOBUFS" int
+    let enodata = constant "UV_ENODATA" int
     let enodev = constant "UV_ENODEV" int
     let enoent = constant "UV_ENOENT" int
     let enomem = constant "UV_ENOMEM" int
@@ -88,6 +89,7 @@ struct
     let esrch = constant "UV_ESRCH" int
     let etimedout = constant "UV_ETIMEDOUT" int
     let etxtbsy = constant "UV_ETXTBSY" int
+    let eunatch = constant "UV_EUNATCH" int
     let exdev = constant "UV_EXDEV" int
     let unknown = constant "UV_UNKNOWN" int
     let eof = constant "UV_EOF" int
@@ -139,6 +141,16 @@ struct
     let () = seal t
   end
 
+  module Metrics =
+  struct
+    type t = [ `Metrics ] structure
+    let t : t typ = typedef (structure "`Metrics") "uv_metrics_t"
+    let loop_count = field t "loop_count" uint64_t
+    let events = field t "events" uint64_t
+    let events_waiting = field t "events_waiting" uint64_t
+    let () = seal t
+  end
+
   module Buf =
   struct
     type t = [ `Buf ] structure
@@ -553,6 +565,8 @@ struct
 
     let t : ([ `Pipe ] Stream.t) typ = typedef (structure "`Pipe") "uv_pipe_t"
     let () = seal t
+
+    let no_truncate = constant "UV_PIPE_NO_TRUNCATE" int
   end
 
   module TTY =
@@ -657,6 +671,8 @@ struct
       let windows_hide = constant "UV_PROCESS_WINDOWS_HIDE" int
       let windows_hide_console = constant "UV_PROCESS_WINDOWS_HIDE_CONSOLE" int
       let windows_hide_gui = constant "UV_PROCESS_WINDOWS_HIDE_GUI" int
+      let windows_file_path_exact_name =
+        constant "UV_PROCESS_WINDOWS_FILE_PATH_EXACT_NAME" int
     end
 
     module Redirection =
@@ -799,6 +815,15 @@ struct
       let no_flags = constant "UV_THREAD_NO_FLAGS" int
       let has_stack_size = constant "UV_THREAD_HAS_STACK_SIZE" int
     end
+
+    module Priority =
+    struct
+      let highest = constant "UV_THREAD_PRIORITY_HIGHEST" int
+      let above_normal = constant "UV_THREAD_PRIORITY_ABOVE_NORMAL" int
+      let normal = constant "UV_THREAD_PRIORITY_NORMAL" int
+      let below_normal = constant "UV_THREAD_PRIORITY_BELOW_NORMAL" int
+      let lowest = constant "UV_THREAD_PRIORITY_LOWEST" int
+    end
   end
 
   module TLS =
@@ -946,6 +971,13 @@ struct
     let shell = field t "shell" string_opt
     let homedir = field t "homedir" string
     let () = seal t
+
+    let group : ([ `Group ] structure) typ =
+      typedef (structure "`Group") "uv_group_t"
+    let groupname = field group "groupname" string
+    let group_gid = field group "gid" ulong
+    let members = field group "members" (ptr (ptr char))
+    let () = seal group
   end
 
   module Time =
@@ -958,6 +990,18 @@ struct
       let usec = field t "tv_usec" int32_t
       let () = seal t
     end
+
+    module Timespec =
+    struct
+      let t : ([ `Timespec ] structure) typ =
+        typedef (structure "`Timespec64") "uv_timespec64_t"
+      let sec = field t "tv_sec" int64_t
+      let nsec = field t "tv_nsec" int32_t
+      let () = seal t
+
+      let monotonic = constant "UV_CLOCK_MONOTONIC" int
+      let real_time = constant "UV_CLOCK_REALTIME" int
+    end
   end
 
   module Env_item =
