@@ -45,12 +45,14 @@ type t = [
   | `EISDIR
   | `ELOOP
   | `EMFILE
+  | `EMLINK
   | `EMSGSIZE
   | `ENAMETOOLONG
   | `ENETDOWN
   | `ENETUNREACH
   | `ENFILE
   | `ENOBUFS
+  | `ENODATA
   | `ENODEV
   | `ENOENT
   | `ENOMEM
@@ -64,6 +66,8 @@ type t = [
   | `ENOTSOCK
   | `ENOTSUP
   | `ENOTTY
+  | `ENXIO
+  | `EOF
   | `EOVERFLOW
   | `EPERM
   | `EPIPE
@@ -78,11 +82,9 @@ type t = [
   | `ESRCH
   | `ETIMEDOUT
   | `ETXTBSY
+  | `EUNATCH
   | `EXDEV
   | `UNKNOWN
-  | `EOF
-  | `ENXIO
-  | `EMLINK
 ]
 
 let to_c = let open C.Types.Error in function
@@ -127,12 +129,14 @@ let to_c = let open C.Types.Error in function
   | `EISDIR -> eisdir
   | `ELOOP -> eloop
   | `EMFILE -> emfile
+  | `EMLINK -> emlink
   | `EMSGSIZE -> emsgsize
   | `ENAMETOOLONG -> enametoolong
   | `ENETDOWN -> enetdown
   | `ENETUNREACH -> enetunreach
   | `ENFILE -> enfile
   | `ENOBUFS -> enobufs
+  | `ENODATA -> enodata
   | `ENODEV -> enodev
   | `ENOENT -> enoent
   | `ENOMEM -> enomem
@@ -146,6 +150,8 @@ let to_c = let open C.Types.Error in function
   | `ENOTSOCK -> enotsock
   | `ENOTSUP -> enotsup
   | `ENOTTY -> enotty
+  | `ENXIO -> enxio
+  | `EOF -> eof
   | `EOVERFLOW -> eoverflow
   | `EPERM -> eperm
   | `EPIPE -> epipe
@@ -160,11 +166,9 @@ let to_c = let open C.Types.Error in function
   | `ESRCH -> esrch
   | `ETIMEDOUT -> etimedout
   | `ETXTBSY -> etxtbsy
+  | `EUNATCH -> eunatch
   | `EXDEV -> exdev
   | `UNKNOWN -> unknown
-  | `EOF -> eof
-  | `ENXIO -> enxio
-  | `EMLINK -> emlink
 
 let from_c = let open C.Types.Error in function
   | e when e = e2big -> `E2BIG
@@ -208,6 +212,7 @@ let from_c = let open C.Types.Error in function
   | e when e = eisdir -> `EISDIR
   | e when e = eloop -> `ELOOP
   | e when e = emfile -> `EMFILE
+  | e when e = emlink -> `EMLINK
   | e when e = emsgsize -> `EMSGSIZE
   | e when e = enametoolong -> `ENAMETOOLONG
   | e when e = enetdown -> `ENETDOWN
@@ -227,6 +232,8 @@ let from_c = let open C.Types.Error in function
   | e when e = enotsock -> `ENOTSOCK
   | e when e = enotsup -> `ENOTSUP
   | e when e = enotty -> `ENOTTY
+  | e when e = enxio -> `ENXIO
+  | e when e = eof -> `EOF
   | e when e = eoverflow -> `EOVERFLOW
   | e when e = eperm -> `EPERM
   | e when e = epipe -> `EPIPE
@@ -243,9 +250,6 @@ let from_c = let open C.Types.Error in function
   | e when e = etxtbsy -> `ETXTBSY
   | e when e = exdev -> `EXDEV
   | e when e = unknown -> `UNKNOWN
-  | e when e = eof -> `EOF
-  | e when e = enxio -> `ENXIO
-  | e when e = emlink -> `EMLINK
   | _ -> `UNKNOWN
 
 let result_from_c error_code =
@@ -294,7 +298,7 @@ let to_result success_value error_code =
   else
     Error (from_c error_code)
 
-let to_result_lazy get_success_value error_code =
+let to_result_f get_success_value error_code =
   if error_code >= 0 then
     Ok (get_success_value ())
   else
