@@ -32,28 +32,58 @@ let pipe ?(read_flags = [`NONBLOCK]) ?(write_flags = [`NONBLOCK]) () =
     fds
     (convert_flags read_flags)
     (convert_flags write_flags)
-  |> Error.to_result_lazy Ctypes.(fun () ->
+  |> Error.to_result_f Ctypes.(fun () ->
     File.from_int (!@ fds), File.from_int (!@ (fds +@ 1)))
 
 let open_ pipe file =
   C.Functions.Pipe.open_ pipe (File.to_int file)
   |> Error.to_result ()
 
-let bind pipe name =
-  C.Blocking.Pipe.bind pipe name
+let bind ?(no_truncate = false) pipe name =
+  let use_bind2 =
+    match name.[0] with
+    | '\x00' -> true
+    | _ -> no_truncate
+    | exception Invalid_argument _ -> no_truncate
+  in
+  begin if use_bind2 then
+    let length = String.length name |> Unsigned.Size_t.of_int in
+    let no_truncate = if no_truncate then C.Types.Pipe.no_truncate else 0 in
+    C.Blocking.Pipe.bind2 pipe name length no_truncate
+  else
+    C.Blocking.Pipe.bind pipe name
+  end
   |> Error.to_result ()
 
-let connect pipe name_or_path callback =
+let connect ?(no_truncate = false) pipe name_or_path callback =
   let request = Stream.Connect_request.make () in
   let callback result =
     Error.catch_exceptions callback (Error.to_result () result)
   in
   Request.set_callback request callback;
-  C.Functions.Pipe.connect
-    request
-    pipe
-    (Ctypes.ocaml_string_start name_or_path)
-    Stream.Connect_request.trampoline
+  let use_connect2 =
+    match name_or_path.[0] with
+    | '\x00' -> true
+    | _ -> no_truncate
+    | exception Invalid_argument _ -> no_truncate
+  in
+  let c_name_or_path = Ctypes.ocaml_string_start name_or_path in
+  if use_connect2 then
+    let length = String.length name_or_path |> Unsigned.Size_t.of_int in
+    let no_truncate = if no_truncate then C.Types.Pipe.no_truncate else 0 in
+    C.Functions.Pipe.connect2
+      request
+      pipe
+      c_name_or_path
+      length
+      no_truncate
+      Stream.Connect_request.trampoline
+  else
+    C.Functions.Pipe.connect
+      request
+      pipe
+      c_name_or_path
+      Stream.Connect_request.trampoline
 
 let rec generic_getname ?(buffer_size = 128) c_function pipe =
   let length_cell =
