@@ -3,11 +3,11 @@
 
 
 
-val check_success_result : string -> ('a, Luv.Error.t) Result.result -> 'a
+val check_success_result : string -> ('a, Luv.Error.t) result -> 'a
 val check_error_result :
-  string -> Luv.Error.t -> (_, Luv.Error.t) Result.result -> unit
+  string -> Luv.Error.t -> (_, Luv.Error.t) result -> unit
 val check_error_results :
-  string -> Luv.Error.t list -> (_, Luv.Error.t) Result.result -> unit
+  string -> Luv.Error.t list -> (_, Luv.Error.t) result -> unit
 val check_error_code : string -> Luv.Error.t -> Luv.Error.t -> unit
 
 val check_not_null : string -> _ Ctypes.ptr -> unit
@@ -33,5 +33,3 @@ type event
 val event : unit -> event
 val defer : event -> (unit -> unit) -> unit
 val proceed : event -> unit
-
-val in_travis : bool
